.. Vumi documentation master file, created by
   sphinx-quickstart on Thu Mar 17 20:51:03 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Vumi's documentation!
================================

Contents:

.. toctree::
   :maxdepth: 1

   overview.rst
   intro/index.rst
   first-smpp-bind.rst
   applications/index.rst
   transports/index.rst
   dispatchers/index.rst
   middleware/index.rst
   metrics.rst
   roadmap.rst
   release-notes.rst

.. note::

   Looking for documentation for writing Javascript applications for the
   hosted Vumi Go environment? Visit http://vumi-go.readthedocs.org for
   documentation on the hosted platform and
   http://vumi-jssandbox-toolkit.readthedocs.org for documentation on
   the Javascript sandbox.

Getting Started:

* :doc:`installation`
* :doc:`getting-started`
* :doc:`Writing your first Vumi app - Part 1</intro/tutorial01>` | :doc:`Part 2</intro/tutorial02>`
* :doc:`ScaleConf workshop instructions</intro/scaleconf01>`

For developers:

.. toctree::
   :maxdepth: 1

   routing-naming-conventions.rst
   how-we-do-releases.rst
   coding-guidelines.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

